/** @module mat2x3 */
/**
 * Returns a 2x3 identity matrix, a short form for a 3x3 matrix with the last row ignored.
 *
 * Row major memory layout:
 *
 * ```
 * 0   1
 * 2   3
 * 4   5
 * ```
 *
 * Equivalent to the column major OpenGL spec:
 *
 * ```
 * 0   3
 * 1   4
 * 2   5
 *
 * m00 m10
 * m01 m11
 * m02 m12
 * ```
 * @returns {mat2x3}
 */
export function create(): mat2x3;
/**
 * Sets a matrix to the identity matrix.
 * @param {mat2x3} a
 * @returns {mat2x3}
 */
export function identity(a: mat2x3): mat2x3;
/**
 * Returns a copy of a matrix.
 * @param {mat2x3} a
 * @returns {mat2x3}
 */
export function copy(a: mat2x3): mat2x3;
/**
 * Sets a matrix from another matrix.
 * @param {mat2x3} a
 * @param {mat2x3} b
 * @returns {mat2x3}
 */
export function set(a: mat2x3, b: mat2x3): mat2x3;
/**
 * Compares two matrices.
 * @param {mat2x3} a
 * @param {mat2x3} b
 * @returns {boolean}
 */
export function equals(a: mat2x3, b: mat2x3): boolean;
/**
 * Multiplies two matrices.
 * @param {mat2x3} a
 * @param {mat2x3} b
 * @returns {mat2x3}
 */
export function mult(a: mat2x3, b: mat2x3): mat2x3;
/**
 * Translates a matrix by a vector.
 * @param {mat2x3} a
 * @param {vec2} v
 * @returns {mat2x3}
 */
export function translate(a: mat2x3, v: vec2): mat2x3;
/**
 * Rotates a matrix by an angle.
 * @param {mat2x3} a
 * @param {Radians} rad
 * @returns {mat2x3}
 */
export function rotate(a: mat2x3, rad: Radians): mat2x3;
/**
 * Scales a matrix by a vector.
 * @param {mat2x3} a
 * @param {vec2} v
 * @returns {mat2x3}
 */
export function scale(a: mat2x3, v: vec2): mat2x3;
