/** @module mat3 */
/**
 * Returns a 3x3 identity matrix.
 *
 * Row major memory layout:
 *
 * ```
 *  0   1   2
 *  3   4   5
 *  6   7   8
 * ```
 *
 *  Equivalent to the column major OpenGL spec:
 *
 * ```
 *   0   3   6
 *   1   4   7
 *   2   5   8
 *
 *  m00 m10 m20
 *  m01 m11 m21
 *  m02 m12 m22
 * ```
 * @returns {mat3}
 */
export function create(): mat3;
/**
 * Sets a matrix to the identity matrix.
 * @param {mat3} a
 * @returns {mat3}
 */
export function identity(a: mat3): mat3;
/**
 * Returns a copy of a matrix.
 * @param {mat3} a
 * @returns {mat3}
 */
export function copy(a: mat3): mat3;
/**
 * Sets a matrix from another matrix.
 * @param {mat3} a
 * @param {mat3} b
 * @returns {mat3}
 */
export function set(a: mat3, b: mat3): mat3;
/**
 * Compares two matrices.
 * @param {mat3} a
 * @param {mat3} b
 * @returns {boolean}
 */
export function equals(a: mat3, b: mat3): boolean;
/**
 * Multiplies two matrices.
 * @param {mat3} a
 * @param {mat3} b
 * @returns {mat3}
 */
export function mult(a: mat3, b: mat3): mat3;
/**
 * Transposes a matrix.
 * @param {mat3} a
 * @returns {mat3}
 */
export function transpose(a: mat3): mat3;
/**
 * Sets matrix to a quaternion.
 * @param {mat3} a
 * @param {quat} q
 * @returns {mat3}
 */
export function fromQuat(a: mat3, q: quat): mat3;
/**
 * Sets a 3x3 matrix from a 2x3 matrix.
 * @param {mat3} a
 * @param {mat2x3} b
 * @returns {mat3}
 */
export function fromMat2x3(a: mat3, b: mat2x3): mat3;
/**
 * Sets a 3x3 matrix to a 4x4 matrix.
 * @param {mat3} a
 * @param {mat4} b
 * @returns {mat3}
 */
export function fromMat4(a: mat3, b: mat4): mat3;
