/**
 * Returns a 4x4 identity matrix.
 *
 * Row major memory layout:
 *
 * ```
 *  0   1   2   3
 *  4   5   6   7
 *  8   9  10  11
 * 12  13  14  15
 * ```
 *
 * Equivalent to the column major OpenGL spec:
 *
 * ```
 *  0   4   8  12
 *  1   5   9  13
 *  2   6  10  14
 *  3   7  11  15
 *
 *  m00 m10 m20 m30
 *  m01 m11 m21 m31
 *  m02 m12 m22 m32
 *  m03 m13 m23 m33
 * ```
 * @returns {mat4}
 */
export function create(): mat4;
/**
 * Sets a matrix to the identity matrix.
 * @param {mat4} a
 * @returns {mat4}
 */
export function identity(a: mat4): mat4;
/**
 * Returns a copy of a matrix.
 * @param {mat4} a
 * @returns {mat4}
 */
export function copy(a: mat4): mat4;
/**
 * Sets a matrix from another matrix.
 * @param {mat4} a
 * @param {mat4} b
 * @returns {mat4}
 */
export function set(a: mat4, b: mat4): mat4;
/**
 * Compares two matrices.
 * @param {mat4} a
 * @param {mat4} b
 * @returns {boolean}
 */
export function equals(a: mat4, b: mat4): boolean;
/**
 * Multiplies two matrices.
 * @param {mat4} a
 * @param {mat4} b
 * @returns {mat4}
 */
export function mult(a: mat4, b: mat4): mat4;
/**
 * Inverts a matrix.
 * @param {mat4} a
 * @returns {mat4}
 */
export function invert(a: mat4): mat4;
/**
 * Transposes a matrix.
 * @param {mat4} a
 * @returns {mat4}
 */
export function transpose(a: mat4): mat4;
/**
 * Translates a matrix by a vector.
 * @param {mat4} a
 * @param {vec3} v
 * @returns {mat4}
 */
export function translate(a: mat4, [x, y, z]: vec3): mat4;
/**
 * Rotates a matrix by an angle at an axis.
 * @param {mat4} a
 * @param {Radians} r
 * @param {vec3} v
 * @returns {mat4}
 */
export function rotate(a: mat4, r: Radians, [x, y, z]: vec3): mat4;
/**
 * Scales a matrix by a vector.
 * @param {mat4} a
 * @param {vec3} v
 * @returns {mat4}
 */
export function scale(a: mat4, [x, y, z]: vec3): mat4;
/**
 * Sets a matrix to a quaternion.
 * @param {mat4} a
 * @param {quat} q
 * @returns {mat4}
 */
export function fromQuat(a: mat4, q: quat): mat4;
/**
 * Sets a matrix to the TRS matrix.
 * @param {mat4} a
 * @param {vec3} v
 * @param {quat} q
 * @param {vec3} s
 * @returns {mat4}
 */
export function fromTranslationRotationScale(a: mat4, v: vec3, q: quat, s: vec3): mat4;
/**
 * Sets a 4x4 matrix to a 3x3 matrix.
 * @param {mat4} a
 * @param {mat3} b
 * @returns {mat4}
 */
export function fromMat3(a: mat4, b: mat3): mat4;
/**
 * Creates a frustum matrix.
 * @param {mat4} a
 * @param {number} left
 * @param {number} right
 * @param {number} bottom
 * @param {number} top
 * @param {number} near
 * @param {number} far
 * @returns {mat4}
 */
export function frustum(a: mat4, left: number, right: number, bottom: number, top: number, near: number, far: number): mat4;
/**
 * Creates a perspective matrix.
 * @param {mat4} a
 * @param {Radians} fovy
 * @param {number} aspectRatio
 * @param {number} near
 * @param {number} far
 * @returns {mat4}
 */
export function perspective(a: mat4, fovy: Radians, aspectRatio: number, near: number, far: number): mat4;
/**
 * Creates an orthographic matrix.
 * @param {mat4} a
 * @param {number} left
 * @param {number} right
 * @param {number} bottom
 * @param {number} top
 * @param {number} near
 * @param {number} far
 * @returns {mat4}
 */
export function ortho(a: mat4, left: number, right: number, bottom: number, top: number, near: number, far: number): mat4;
/**
 * Calculates a lookAt matrix from position, target and up vectors.
 * @param {mat4} a
 * @param {vec3} from
 * @param {vec3} to
 * @param {vec3} up
 * @returns {mat4}
 */
export function lookAt(a: mat4, [eyex, eyey, eyez]: vec3, [targetx, targety, targetz]: vec3, [upx, upy, upz]: vec3): mat4;
