/** @module vec3 */
/**
 * Returns a new vec3 at 0, 0, 0.
 * @returns {vec3}
 */
export function create(): vec3;
/**
 * Returns a copy of a vector.
 * @param {vec3} a
 * @returns {vec3}
 */
export function copy(a: vec3): vec3;
/**
 * Sets a vector to another vector.
 * @param {vec3} a
 * @param {vec3} b
 * @returns {vec3}
 */
export function set(a: vec3, b: vec3): vec3;
/**
 * Compares two vectors.
 * @param {vec3} a
 * @param {vec3} b
 * @returns {boolean}
 */
export function equals(a: vec3, b: vec3): boolean;
/**
 * Adds a vector to another.
 * @param {vec3} a
 * @param {vec3} b
 * @returns {vec3}
 */
export function add(a: vec3, b: vec3): vec3;
/**
 * Subtracts a vector from another.
 * @param {vec3} a
 * @param {vec3} b
 * @returns {vec3}
 */
export function sub(a: vec3, b: vec3): vec3;
/**
 * Scales a vector by a number.
 * @param {vec3} a
 * @param {number} s
 * @returns {vec3}
 */
export function scale(a: vec3, s: number): vec3;
/**
 * Adds two vectors after scaling the second one.
 * @param {vec3} a
 * @param {vec3} b
 * @param {number} s
 * @returns {vec3}
 */
export function addScaled(a: vec3, b: vec3, s: number): vec3;
/**
 * Multiplies a vector by a matrix.
 * @param {vec3} a
 * @param {mat4} m
 * @returns {vec3}
 */
export function multMat4(a: vec3, m: mat4): vec3;
/**
 * Multiplies a vector by a quaternion.
 * @param {vec3} a
 * @param {quat} q
 * @returns {vec3}
 */
export function multQuat(a: vec3, q: quat): vec3;
/**
 * Calculates the dot product of two vectors.
 * @param {vec3} a
 * @param {vec3} b
 * @returns {number}
 */
export function dot(a: vec3, b: vec3): number;
/**
 * Calculates the cross product of two vectors.
 * @param {vec3} a
 * @param {vec3} b
 * @returns {vec3}
 */
export function cross(a: vec3, b: vec3): vec3;
/**
 * Calculates the length of a vector.
 * @param {vec3} a
 * @returns {number}
 */
export function length(a: vec3): number;
/**
 * Calculates the squared length of a vector.
 * @param {vec3} a
 * @returns {number}
 */
export function lengthSq(a: vec3): number;
/**
 * Normalises a vector.
 * @param {vec3} a
 * @returns {vec3}
 */
export function normalize(a: vec3): vec3;
/**
 * Calculates the distance between two vectors.
 * @param {vec3} a
 * @param {vec3} b
 * @returns {number}
 */
export function distance(a: vec3, b: vec3): number;
/**
 * Calculates the squared distance between two vectors.
 * @param {vec3} a
 * @param {vec3} b
 * @returns {number}
 */
export function distanceSq(a: vec3, b: vec3): number;
/**
 * Limits a vector to a length.
 * @param {vec3} a
 * @param {number} len
 * @returns {vec3}
 */
export function limit(a: vec3, len: number): vec3;
/**
 * Linearly interpolates between two vectors.
 * @param {vec3} a
 * @param {vec3} b
 * @param {number} t
 * @returns {vec3}
 */
export function lerp(a: vec3, b: vec3, t: number): vec3;
/**
 * Prints a vector to a string.
 * @param {vec3} a
 * @param {number} [precision=4]
 * @returns {string}
 */
export function toString(a: vec3, precision?: number): string;
